@@ -43,18 +43,12 @@ def ScientificNotation(num):
     elif num == 10:
         return "1x10^1"
     elif num > 10 or num < 0:
-        if num >= 10:
-            while num >= 10:
+        while num >= 10 or num <= 0:
+            if num >= 10:
                 num /= 10
                 revs += 1
-                return str(num) + "x10^" + str(revs)
-        if num <= 0:
-            while num <= 0:
+                return str(num) + "x-10^" + str(revs)
+            elif num <= 0:
                 num /= -10
-                revs += 1
-            num /= -10
-            revs += 1
-            if num < 0:
-                return str(num) + "x10^" + str(revs)
-            else:
-                return str(-num) + "x10^" + str(revs)
\ No newline at end of file
+                revs == 1
+                return str(num) + "x10^" + str(revs)
\ No newline at end of file
